#
# spec file for package python-nbconvert
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif
# X.X.0 gets abbreviated by pythondistdeps
%define shortversion 7.16.6
%{?sle15_python_module_pythons}
Name:           python-nbconvert%{psuffix}
Version:        7.16.6
Release:        1.1
Summary:        Conversion of Jupyter Notebooks
License:        BSD-3-Clause AND MIT
URL:            https://github.com/jupyter/nbconvert
Source0:        https://files.pythonhosted.org/packages/source/n/nbconvert/nbconvert-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling >= 0.25}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       jupyter-nbconvert = %{version}
Requires:       python-Jinja2 >= 3.0
Requires:       python-MarkupSafe >= 2.0
Requires:       python-Pygments >= 2.4.1
Requires:       python-beautifulsoup4
Requires:       python-defusedxml
Requires:       python-jupyter-core >= 4.7
Requires:       python-jupyterlab-pygments
Requires:       python-nbclient >= 0.5
Requires:       python-nbformat >= 5.7
Requires:       python-packaging
Requires:       python-pandocfilters >= 1.4.1
Requires:       python-traitlets >= 5.1
Requires:       (python-tinycss2 >= 1.1.0 with python-tinycss2 < 1.5)
## pyproject.toml says bleach[css], this is bleach w/ tinycss2, see above
Requires:       (python-bleach without python-bleach = 5.0.0)
Requires:       (python-mistune >= 2.0.3 with python-mistune < 4)
Recommends:     pandoc >= 2.9.2
Recommends:     python-tornado >= 6.1
Suggests:       %{name}-latex
Suggests:       python-qtwebengine-qt5 >= 5.15
Provides:       python-jupyter_nbconvert = %{version}
Obsoletes:      python-jupyter_nbconvert < %{version}
BuildArch:      noarch
%if 0%{python_version_nodots} < 310
Requires:       python-importlib-metadata >= 3.6
%endif
%if %{with libalternatives}
BuildRequires:  alts
Requires:       alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
%if %{with test}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module ipywidgets >= 7.5}
BuildRequires:  %{python_module nbconvert = %{version}}
BuildRequires:  %{python_module pytest >= 7}
%endif
%python_subpackages

%description
The jupyter nbconvert package converts notebooks to various other formats
via Jinja templates.

This package provides the python interface.

%package     -n jupyter-nbconvert
Summary:        Conversion of Jupyter Notebooks
Requires:       jupyter-ipykernel
Requires:       jupyter-jupyter-core
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(nbconvert) = %{shortversion}
Suggests:       python3-nbconvert
Conflicts:      python3-jupyter_nbconvert < 5.5.0

%description -n jupyter-nbconvert
The jupyter nbconvert package converts notebooks to various other formats
via Jinja templates.

This package provides the jupyter components.

%package     -n jupyter-nbconvert-latex
Summary:        LaTeX support for nbconvert
Requires:       jupyter-nbconvert = %{version}
Requires:       texlive-bibtex
Requires:       texlive-makeindex
Requires:       tex(adjustbox.sty)
Requires:       tex(eurosym.sty)
Requires:       tex(ulem.sty)

%description -n jupyter-nbconvert-latex
The jupyter nbconvert package converts notebooks to various other formats
via Jinja templates.

This package pulls in the LaTeX dependencies for nbconvert.

%prep
%autosetup -p1 -n nbconvert-%{version}
for f in nbconvert/nbconvertapp.py nbconvert/filters/filter_links.py; do
  sed -i -e '/^#!\//, 1d' $f
  chmod -x $f
done
sed -i '/addopts/,/\]/ s/"--color=yes",//' pyproject.toml

%build
%if ! %{with test}
%pyproject_wheel
%endif

%install
%if ! %{with test}
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/jupyter-nbconvert
%python_clone -a %{buildroot}%{_bindir}/jupyter-dejavu
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_docdir}/jupyter-nbconvert/
%endif

%if %{with test}
%check
export LANG=en_US.UTF-8
export PYTHONDONTWRITEBYTECODE=1
# requires modules not installed: https://github.com/jupyter/nbconvert/issues/1846
donttest="test_convert_full_qualified_name or test_post_processor"
# mv the source out of PYTHONPATH
mv nbconvert nbconvert.moved
%{python_expand #
$python -m ipykernel.kernelspec --user
pytest-%{$python_bin_suffix} -v -m 'not network' -k "not ($donttest)"
}
%endif

%if !%{with test}
%pre
%python_libalternatives_reset_alternative jupyter-nbconvert

%post
%python_install_alternative jupyter-nbconvert jupyter-dejavu

%postun
%python_uninstall_alternative jupyter-nbconvert

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/nbconvert-%{version}.dist-info
%{python_sitelib}/nbconvert/
%python_alternative %{_bindir}/jupyter-nbconvert
%python_alternative %{_bindir}/jupyter-dejavu

%files -n jupyter-nbconvert
%license LICENSE
%dir %{_datadir}/jupyter/
%dir %{_datadir}/jupyter/nbconvert
%{_datadir}/jupyter/nbconvert/templates

%files -n jupyter-nbconvert-latex
%license LICENSE
%endif

%changelog
* Fri Jun  6 2025 Friedrich Haubensak <hsk17@mail.de>
- Update to 7.16.6
  * Prevent leading whitespace in markdown code blocks from being
    stripped
  * Fix bullet list parsing in markdown
  * Fix crash when running with optimization
  * Maintenance and upkeep improvements
- Update to 7.16.5
  * Add support for mistune 3.1.0
  * Allow including text/x-rst outputs in rst conversion,
    transition away from text/restructuredtext
  * Do not display mathjax overlay
  * Work around pip 24.1 bug which prevents installing
    pandocfilters 1.4.1
  * Don't die if template path cannot be read
  * Fix markdown2asciidoc function for pandoc >= 3.0
  * Maintenance and upkeep improvements
* Thu Feb 27 2025 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Aug 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.16.4
  * rst exporter: Re-enable coalescing streams #2142 (@mgeier)
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.16.3
  * Maintenance and upkeep improvements
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.16.2
  * [HTMLExporter] Initialize resources before widget filtering
    [#2118] (@yuvipanda)
- Release 7.16.1 is pure maintenance
- Skip testing python39: no longer supported since ipython 8.19
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- update to 7.16.0:
  * Add a toggle to skip the svg encoding of images #2106
  * Support configurable width and height of reveal presentations
* Sun Jan 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 7.14.2 via 7.14.1, 7.14.0
  * Fix broken image scaling in case a custom width or height is
    provided for the image #2094 (@AndSte01)
  * Convert coalescese_streams function to
    CoalesceStreamsPreprocessor #2089 (@ryan-williams)
  * Fix webpdf test on Python 3.12 #2088 (@blink1073)
* Thu Dec 28 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.13.1
  * Restore removed import #2086 (@blink1073)
- Release 7.13.0
  * Add table, td, tr to allowed list of tags #2083 (@yuvipanda)
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 7.12.0:
  * Allow to load config from env.
  * Use ruff on notebooks and update typings
  * update Python version support in docs
  * Support es modules in js includes
  * Clean up lint handling and list generics
  * Remove not needed pytest-dependency test requirement
  * Update to mermaid 10.6.0, docs keyboard navigation
  * Fix typing for traitlets 5.13
  * Adopt ruff format
  * Update typings and remove dead link
  * Update to mermaid 10.6.0, docs keyboard navigation
* Mon Oct  9 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.9.2
  * Restore ResourcesDict to the public API #2055 (@blink1073)
- Release 7.9.1
  * Include tests in sdist #2053 (@blink1073)
- Release 7.9.0
  * Update to mermaidjs 10.5.0 #2051 (@bollwyvl)
  * Update typing for traitlets 5.11 #2050 (@blink1073)
  * Fixup typings #2048 (@blink1073)
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.8.0
  * MermaidJS 10.3.1, accessibility features, handle MIME #2034
    (@bollwyvl)
  * Fix: Prevent error from all whitespace lang string #2036
    (@Adamtaranto)
* Sat Aug 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.7.4
  * Give main tag a height of 100%% in css for reveal html #2032
    (@lkeegan)
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Suggest primary python package -- boo#1214354
* Sat Aug  5 2023 Arun Persaud <arun@gmx.de>
- specfile
  * require flaky for tests
- update to version 7.7.3:
  * Bugs fixed
    + Restore pauses during webpdf render #2025 (@jstorrs)
- changes from version 7.7.2:
  * Bugs fixed
    + Show a warning if an image has no alternative text #2024
    (@brichet)
- changes from version 7.7.1:
  * Bugs fixed
    + Restore 'media=print' option #2022 (@brichet)
- changes from version 7.7.0:
  * Enhancements made
    + [Accessibility] some accessibility improvements #2021 (@brichet)
    + Adopt playwright #2013 (@brichet)
    + Update to Jupyterlab 4 #2012 (@brichet)
  * Bugs fixed
    + html: write image/svg+xml data as base64 and skip clean_html
    [#2018] (@jstorrs)
    + Remove HTML escaping JSON-encoded widget state #1934 (@manzt)
  * Maintenance and upkeep improvements
    + Fix lint error #2010 (@blink1073)
    + Support Python 3.8-3.12 #2008 (@blink1073)
* Tue Jun 20 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.6.0
  * Update to Mistune v3 #1820 (@TiagodePAlves)
- Release 7.5.0
  * Add mermaidjs 10.2.3 #1957 (@bollwyvl)
  * Fix pdf conversion with explicitly relative paths #2005
    (@tuncbkose)
  * Ensure TEXINPUTS is an absolute path #2002 (@tuncbkose)
* Sun Jun 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.4.0
  * Add ExtractAttachmentsPreprocessor #1978 (@tuncbkose)
  * Moved ensure_dir_exists to FilesWriter #1987 (@tuncbkose)
  * Tweak exporter default_config merging behavior #1981
    (@tuncbkose)
  * Revert unintended effects of #1966 #1974 (@tuncbkose)
* Mon May  1 2023 Ben Greiner <code@bnavigator.de>
- Skip a test broken by ipython 8.13
  * test_errors_print_traceback: gh#jupyter/nbconvert#1985
* Sun Apr 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.3.1
  * Remove overwriting of default KernelManager #1972 (@tuncbkose)
- Release 7.3.0
  * Allow pattern in output_base #1967 (@JeppeKlitgaard)
  * Make date configurable in latex/PDF #1963 (@achimgaedke)
  * Update jupyterlab CSS #1960 (@martinRenou)
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.2.10
  * Add cell-id anchor for cell identification #1897 (@krassowski)
  * Do not import pyppeteer for installation check #1947
    (@krassowski)
* Thu Feb  9 2023 Arun Persaud <arun@gmx.de>
- update to version 7.2.9:
  * Bugs fixed
    + Fix handling of css sanitizer #1940 (@blink1073)
* Sun Jan 22 2023 Ben Greiner <code@bnavigator.de>
- Update to 7.2.8
  * always pass relax_add_props=True when validating #1936 (@minrk)
* Mon Dec 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 7.2.7
  * Fix Hanging Tests on Linux #1924 (@blink1073)
- Release 7.2.6
  * Include all templates in sdist #1916 (@blink1073)
- Release 7.2.5
  * Fix for webpdf print margins #1907 (@JWock82)
- Release 7.2.4
  * Handle jupyter core warning #1905 (@blink1073)
  * Add Py-typed marker. #1898 (@Carreau)
- Release 7.2.3
  * clean_html: allow SVG tags and SVG attributes #1890 (@akx)
* Wed Oct 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 7.2.2
  * Fix default config test #1885 (@blink1073)
  * Add ensure label workflow #1884 (@blink1073)
  * Add release workflows #1883 (@blink1073)
  * Maintenance cleanup #1881 (@blink1073)
- Release 7.2.1
  * Fix version handling #1878 (@blink1073)
- Release 7.2.0
  * Prep for jupyter releaser #1877 (@blink1073)
  * Add support for jupyter_client 8 #1867 (@blink1073)
- Release 7.1.0
  * Fix markdown table not render bug by @Neutree in #1853
  * Replace lxml.html.clean_html with bleach; drop lxml dependency
    by @akx in #1854
  * Remove CircleCI badge from README by @akx in #1857
  * Added support for section (slide) "data-*" attributes by
    @bouzidanas in #1861
- Drop ignore-bleach-deprecation-test.patch
* Sun Sep 25 2022 Ben Greiner <code@bnavigator.de>
- Update to version 7.0.0
  * Update to Mistune 2.0.2 by @TiagodePAlves in #1764
  * Clean up markdown parsing by @blink1073 in #1774
  * Switch to hatch build backend by @blink1073 in #1777
  * switch from entrypoints to importlib-metadata by @konstin in
    [#1782]
  * Add recursive flag for glob notebook search by @paoloalba in
    [#1785]
  * Updates for sphinx 5.0 support by @blink1073 in #1788
  * Fixed unique div ids in lab template, fixed #1759 by @veghdev
    in #1761
  * WebPDFExporter: Emulate media print by @martinRenou in #1791
  * Fix fonts overriden by user stylesheet by inheriting styles by
    @dakoop in #1793
  * Fix lab template output alignment by @dakoop in #1795
  * Add qtpdf and qtpng exporters by @davidbrochart in #1611
  * Fix linters by @martinRenou in #1825
  * Remove downloaded CSS from repository by @martinRenou in #1827
  * escape_html: prevent escaping quotes on widgets JSON reprs
    (#1829) by @martinRenou in #1830
  * Remove tests from bdist by @TiagodePAlves in #1822
  * Encode SVG image data as UTF-8 before calling lxml cleaner
    (fixes #1836) by @emarsden in #1837
  * Handle nbformat 5.5 by @blink1073 in #1841
- Drop nbconvert-vendorize-mistune.patch and mistune 0.8.4 sources.
* Thu Aug 11 2022 Arun Persaud <arun@gmx.de>
- specfile
  * remove skip python 2, since we require python >= 3.7 anyway
  * updates patches
  * require lxml
- update to version 6.5.3:
  * Fix title (#1833)
- changes from version 6.5.2:
  * escape_html: prevent escaping quotes on widgets JSON reprs (#1829)
  * Fix linters (#1828)
  * pre-commit-ci[bot] authored and SylvainCorlay committed 2 days ago
  * Remove downloaded CSS from repository
- changes from version 6.5.1:
  * Fix pre-commit
  * Fix tests
  * Run black and prettier
  * Run test on 6.x branch
  * Convert input to string prior to escape HTML
  * Check input type before escaping
  * GHSL-2021-1017, GHSL-2021-1020, GHSL-2021-1021
  * GHSL-2021-1026, GHSL-2021-1025
  * GHSL-2021-1024
  * GHSL-2021-1023
  * GHSL-2021-1022
  * GHSL-2021-1019
  * GHSL-2021-1018
  * GHSL-2021-1027, GHSL-2021-1028
  * GHSL-2021-1014, GHSL-2021-1015, GHSL-2021-1016
  * GHSL-2021-1013
* Sun Jun  5 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.5.0
  * Drop dependency on testpath. by @anntzer in #1723
  * Apply Autoformatters by @blink1073 in #1746
  * support bleach 5, add packaging and tinycss2 dependencies by
    @bollwyvl in #1755
  * update cli example by @leahecole in #1753
- Refresh nbconvert-vendorize-mistune.patch, include
  gh#lepture/mistune#188 for successful import
- Add ignore-bleach-deprecation-test.patch because the test suite
  fails with a DeprecationWarning for bleach <5 otherwise.
* Sat Mar 12 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update nbconvert-vendorize-mistune.patch (linenumbers changed and lines before patch)
  * require beautiful-soup
- update to version 6.4.4:
  * HTMLExporter: Respect the embed_images flag for HTML blocks PR
    [#1721]
- changes from version 6.4.3:
  * Remove ipython genutils PR #1727
  * Add section to customizing showing how to use template inheritance
    PR #1719
* Sat Feb 19 2022 Arun Persaud <arun@gmx.de>
- update to version 6.4.2:
  * Adding theme support for WebPDF exporter (#1718)
  * Add option to embed_images in Markdown cells (#1717)
  * HTMLExporter: Add theme alias and docs (#1716)
  * Add basic support for federated labextensions themes (#1703)
  * Always hide the collapser element (#1712)
  * Raise pyppeteer requirement to >=1,<1.1 (#1711)
- changes from version 6.4.1:
  * CodeMirror style bleed fix (#1710)
  * Fix DOM structure of markdown cells in lab template (#1709)
  * Fix styling regression (#1708)
  * Handle needs_background cell metadata (#1704)
* Fri Jan  7 2022 Ben Greiner <code@bnavigator.de>
- Don't build on Python 3.6 (SLE/Leap backports safeguard)
* Thu Jan  6 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.4.0
  * Optionally speed up validation by @gwincr11 in #1672
  * Adding missing div compared to JupyterLab DOM structure by
    @SylvainCorlay in #1678
  * Allow passing extra args to code highlighter by @yuvipanda in
    [#1683]
  * Prevent page breaks in outputs when printing by @SylvainCorlay
    in #1679
  * Add collapsers to template by @SylvainCorlay in #1689
  * Fix recent pandoc latex tables by adding calc and array (#1536,
    [#1566]) by @cgevans in #1686
  * Add an invalid notebook error by @gwincr11 in #1675
  * Fix typos in execute.py by @TylerAnderson22 in #1692
  * Modernize latex greek math handling (partially fixes #1673) by
    @cgevans in #1687
  * Fix use of deprecated API and update test matrix by @blink1073
    in #1696
  * Update nbconvert_library.ipynb by @letterphile in #1695
  * Changelog for 6.4 by @blink1073 in #1697
- Remove the doc package
* Fri Dec 31 2021 Ben Greiner <code@bnavigator.de>
- Now update to 6.3.0
  * traitlets 5 is ready
  * for changelog see below
* Fri Dec 31 2021 Ben Greiner <code@bnavigator.de>
- Revert to 6.0.7
  * We can't have a newer version without traitlets 5. But we
    can't have traitlets 5 as long as python36 is active
- Vendorize mistune 0.8.4
  * Add nbconvert-vendorize-mistune.patch
  * gh#jupyter/nbconvert#1685
- Alternativize flavored entry-point. For 6.3: do it with dejavu
* Thu Dec 30 2021 Matej Cepl <mcepl@suse.com>
- Upgrade to the version 6.3.0:
  - Bugfixes:
  - Update state filter
  - Add slide numbering
  - Fix HTML templates mentioned in help docs
  - Add the ability to fully customize widget_renderer_url
  - Enable users to customize MathJax URLs
  - Add CLI configuration for disable-chromium-sandbox
  - Enables webpdf to be rendered with templates
  - Adds dejavu
  - Significant Changes¶
  - Dropped Python 3.6 and added Python 3.9
  - Convert execute preprocessor wrapper to resemble papermill
  - Comprehensive notes¶
  - Feature: support static widgets in Reveal.js slides PR
    [#1553]:
  - Feature: add speaker notes to Reveal.js template
  - Add correct output mimetype to WebPDF exporter
  - Set mimetype for webpdf correctly
  - Fix docstring issue and a broken link
  - Add CLI example for removing cell tag syntax
  - Include output of stdin stream in lab template
  - Don’t use a shell to call inkscape
  - JupyterLab export as HTML with widgets fails to load
    widgets
  - Move note inside Reveal.js HTML slideshow
  - fix issue 1507: broken command line option
    –CSSHTMLHeaderPreprocessor.style=
  - Fix order of template paths
  - Changed documentation of external_exporters
  - Fix template precedence when using a custom template
  - add pip to docs envt
  - Fix CI By Adding PIP to conda envt for docs build
  - Explicitly install pip in docs environment.yml
  - small update to docs hide cell
  - Allow child templates to override mathjax
  - Allow get_export_names to skip configuration check
  - Update docs: Tex Live package on Ubuntu
  - Test jupyter_client
  - Update jupyterlab css
  - Webpdf: Use a temporary file instead of an URL
  - Applied patch for marking network changes
  - Change webpdf display name
  - Allow disabling pyppeteer sandbox
  - Make pagination configurable in webpdf
  - Fix Reveal.js version in documentation
  - Fix dangling reference to get_template_paths()
  - Solved svg2pdf conversion error if Inkscape is installed
    into the default path on a windows machine
  - Update version dependency of traitlets
  - Update execute.py
  - Fix code output indentation when running nbconvert
    –no-input
  - #1428 add docstring
  - Update nbconvert_library.ipynb
  - Supports isolated iframe when converting to HTML
* Thu Dec 30 2021 Matej Cepl <mcepl@suse.com>
- Upgrade to the version 6.3.0:
  - Bugfixes:
  - Update state filter
  - Add slide numbering
  - Fix HTML templates mentioned in help docs
  - Add the ability to fully customize widget_renderer_url
  - Enable users to customize MathJax URLs
  - Add CLI configuration for disable-chromium-sandbox
  - Enables webpdf to be rendered with templates
  - Adds dejavu
  - Significant Changes
  - Dropped Python 3.6 and added Python 3.9
  - Convert execute preprocessor wrapper to resemble papermill
  - Comprehensive notes
  - Feature: support static widgets in Reveal.js slides PR
    [#1553]:
  - Feature: add speaker notes to Reveal.js template
  - Add correct output mimetype to WebPDF exporter
  - Set mimetype for webpdf correctly
  - Fix docstring issue and a broken link
  - Add CLI example for removing cell tag syntax
  - Include output of stdin stream in lab template
  - Don’t use a shell to call inkscape
  - JupyterLab export as HTML with widgets fails to load
    widgets
  - Move note inside Reveal.js HTML slideshow
  - fix issue 1507: broken command line option
    –CSSHTMLHeaderPreprocessor.style=
  - Fix order of template paths
  - Changed documentation of external_exporters
  - Fix template precedence when using a custom template
  - add pip to docs envt
  - Fix CI By Adding PIP to conda envt for docs build
  - Explicitly install pip in docs environment.yml
  - small update to docs hide cell
  - Allow child templates to override mathjax
  - Allow get_export_names to skip configuration check
  - Update docs: Tex Live package on Ubuntu
  - Test jupyter_client
  - Update jupyterlab css
  - Webpdf: Use a temporary file instead of an URL
  - Applied patch for marking network changes
  - Change webpdf display name
  - Allow disabling pyppeteer sandbox
  - Make pagination configurable in webpdf
  - Fix Reveal.js version in documentation
  - Fix dangling reference to get_template_paths()
  - Solved svg2pdf conversion error if Inkscape is installed
    into the default path on a windows machine
  - Update version dependency of traitlets
  - Update execute.py
  - Fix code output indentation when running nbconvert
    –no-input
  - #1428 add docstring
  - Update nbconvert_library.ipynb
  - Supports isolated iframe when converting to HTML
* Sat Oct 30 2021 Ben Greiner <code@bnavigator.de>
- Do not require webpdf extra pyppeteer on tests. Not usefully
  used in offline testing, not available for python36.
- Drop skip_network_tests.patch (upstreamed for 6.1) not required
  due to the above
- Note: we have to stay on version 6.0 until the whole python36
  stack is removed from entire TW or the Jupyter ecosystem on TW.
* Thu Apr  8 2021 Ben Greiner <code@bnavigator.de>
- Actually break the cycle: test flavor needs a psuffix
* Wed Mar 31 2021 Ben Greiner <code@bnavigator.de>
- Test in multibuild in order to break build dependency cycle with
  nbclient
* Sun Feb 28 2021 Ben Greiner <code@bnavigator.de>
- Add missing runtime requirement of nbclient. Keep the minversion
- Remove empty html templates dir after test runs. This directory
  installed with mode 700 caused other package test suites to fail.
* Thu Feb 25 2021 Matej Cepl <mcepl@suse.com>
- Update to 6.0.7:
  - 6.0.7
  - Primarly a release addressing template extensions issues reported
    since 6.0 launched.
  - 6.0.6
  - A range of bug fixes for webpdf exports
  - 6.0.5
  - Revert networkidle2 change which caused custom cdn-fetched widgets
    in webpdf
  - 6.0.4
  - Bugfixes only
  - 6.0.3
  - Execute preprocessor no longer add illegal execution counts to
    markdown cells :ghpull:`1396`:
  - 6.0.2
  - A patch for a few minor issues raised out of the 6.0 release.
  - 6.0.1
  - A quick patch to fix an issue with get_exporter :ghpull:`1367`:
  - 6.0
  - Nbconvert 6.0 is a major release of nbconvert which includes many
    significant changes.
  - Python 2 support was dropped. Currently Python 3.6-3.8 is
    supported and tested by nbconvert. However, nbconvert 6.0
    provides limited support for Python 3.6. nbconvert 6.1 will drop
    support for Python 3.6. Limited support means we will test and
    run CI on Python 3.6.12 or higher. Issues that are found only
    affecting Python 3.6 are not guaranteed to be fixed. We
    recommend all users of nbconvert use Python 3.7 and higher.
  - Unlike previous versions, nbconvert 6.0 relies on the nbclient
    package for the execute preprocessor, which allows for
    asynchronous kernel requests.
  - template_path has become template_paths. If referring to a 5.x
    style .tpl template use the full path with the template_file
    argument to the file. On the command line the pattern is
  - -template-file=<path/to/file.tpl>.
  - Nbconvert 6.0 includes a new "webpdf" exporter, which renders
    notebooks in pdf format through a headless web browser, so that
    complex outputs such as HTML tables, or even widgets are
    rendered in the same way as with the HTML exporter and a web
    browser.
  - The default template applied when exporting to HTML now produces
    the same DOM structure as JupyterLab, and is styled using
    JupyterLab's CSS. The pygments theme in use mimics JupyterLab's
    codemirror mode with the same CSS variables, so that custom
    JupyterLab themes could be applied. The classic notebook styling
    can still be enabled with
  - jupyter nbconvert --to html --template classic
  - Nbconvert 6.0 includes a new system for creating custom
    templates, which can now be installed as packages. A custom
    "foobar" template is installed in Jupyter's data directory under
    nbconvert/templates and has the form of a directory containing
    all resources. Templates specify their base template as well as
    other configuration parameters in a conf.json at the root of the
    template directory.
  - The "slideshow" template now makes use of RevealJS version 4. It
    can now be used with the HTML exporter with
  - jupyter nbconvert --to html --template reveal
  - The --to slides exporter is still supported for convenience.
  - Inkscape 1.0 is now supported, which had some breaking changes
    that prevented 5.x versions of nbconvert from converting
    documents on some systems that updated.
- Add skip_network_tests.patch to skip tests requiring network
  access (gh#jupyter/nbconvert#1526).
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Temporarily disable test_run_all_notebooks as it fails on
  python 3.8
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.6.1
  + New Features
  * Add support for alt tags for jpeg and png images
  * Allow HTML header anchor text to be HTML
  * Change RegExRemove to remove code cells with output
  * Added cell tag data attributes to HTML exporter
  + Fixing Problems
  * Update svg2pdf.py to search the PATH for inkscape
  * Fix latex dependencies installation command for Ubuntu systems
  + Testing, Docs, and Builds
  * Added Circle CI builds for documentation
  * Fix typo in argument name in docstring (TagRemovePreprocessor)
  * Changelog typo fix
  * Updated API page for TagRemovePreprocessor and TemplateExporter
  * Added remove_input_tag traitlet to the docstring
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.6.0
  + New Features
  * Make a default global location for custom user templates
  * Parallel execution improvements
  * Added ``store_history`` option to ``preprocess_cell`` and ``run_cell``
  * Simplify the function signature for preprocess()
  * Set flag to not always stop kernel execution on errors
  * ``setup_preprocessor`` passes kwargs to ``start_new_kernel``
  + Fixing Problems
  * Very fast stream outputs no longer drop some messages
  * LaTeX errors now properly raise exceptions
  * Improve template whitespacing
  * Fixes for character in LaTeX exports and filters
  * Mistune pinned in preparation for 2.0 release
  * Require mock only on Python 2
  * Fix selection of mimetype when converting to HTML
  * Correct a few typos
  * Update ``export_from_notebook`` names
  * Dedenting html in ExtractOutputPreprocessor
  * Fix backwards incompatibility with markdown2html
  * Fixed html image tagging
  * Remove unnecessary css
  + Testing, Docs, and Builds
  * Pip-install nbconvert on readthedocs.org
  * Fix various doc build issues
  * Add issue templates
  * Added instructions for bumping the version forward when releasing
  * Fix Testing on Windows
  * Refactored ``test_run_notebooks``
  * Fixed documentation typos
* Wed May 15 2019 Todd R <toddrme2178@gmail.com>
- Add conflicts to jupyter subpackage to more explicitly handle
  file overlaps with old naming scheme.
* Fri Apr 26 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.5.0:
  + New Features
  * IPyWidget Support
  * A new ClearMetadata Preprocessor is available
  * Support for pandoc 2
  * New, and better, latex template
  + Fixing Problems
  * Refactored execute preprocessor to have a process_message function
  * Fixed OOM kernel failures hanging
  * Fixed latex export for svg data in python 3
  * Enabled configuration to be shared to exporters from script exporter
  * Make latex errors less verbose
  * Typo in template syntax
  * Improved attachments +fix supporting non-unique names
  * PDFExporter "output_mimetype" traitlet is not longer 'text/latex'
  * FIX: respect wait for clear_output
  * address deprecation warning in cgi.escape
  * Correct inaccurate description of available LaTeX template
  * Fixed kernel death detection for executions with timeouts
  * Fixed export names for various templates
  + Deprecations
  * Dropped support for python 3.4
  * Removed deprecated ``export_by_name``
  + Testing, Docs, and Builds
  * Added tests for each branch in execute's run_cell method
  * Mention formats in --to options more clearly
  * Adds ascii output type to command line docs page, mention image folder output
  * Simplify setup.py
  * Use utf-8 encoding in execute_api example
  * Upgrade pytest on Travis
  * Fix LaTeX base template name in docs
  * Updated release instructions based on 5.4 release walk-through
  * Fixed broken link to jinja docs
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
- Rename doc package to match jupyter package name.
* Wed Mar 13 2019 Matej Cepl <mcepl@suse.com>
- Update to 5.4.1:
  - New Features
  - Expose pygments styles
  - Tornado 6.0 support -- Convert proxy handler from callback
    to coroutine
  - Add option to overwrite the highlight_code filter
  - Fixing Problems
  - Mathjax.tpl fix for rendering Latex in html
  - Backwards compatbility for empty kernel names
  - Testing, Docs, and Builds
  - DOC: Add missing language specification to code-block
- Switch to %%pytest
* Tue Nov 20 2018 Todd R <toddrme2178@gmail.com>
- Disable test due to use of old IPython reference files.
  See https://github.com/jupyter/nbconvert/issues/898
* Mon Sep 10 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrasing for summary.
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 5.4.0
  + New Features
  * No input flag (``--no-input``)
  * Add alias ``--to ipynb`` for notebook exporter
  * Add ``export_from_notebook``
  * If set, use ``nb.metadata.authors`` for LaTeX author line
  * Populate language_info metadata when executing
  * Support for ``\mathscr``
  * Allow the execute preprocessor to make use of an existing kernel
  * Refactor ExecutePreprocessor
  * Update widgets CDN for ipywidgets 7 w/fallback
  * Add support for adding custom exporters to the "Download as" menu.
  * Enable ANSI underline and inverse
  * Update notebook css to 5.4.0
  * Change default for slides to direct to the reveal cdn rather than locally
  * Use "title" instead of "name" for metadata to match the notebook format
  * Img filename metadata
  * Added MathJax compatibility definitions
  * Per cell exception
  * Simple API for in-memory templates
  * Set BIBINPUTS and BSTINPUTS environment variables when making PDF
  * If ``nb.metadata.title`` is set, default to that for notebook
  + Deprecations
  * Drop support for python 3.3
  + Fixing Problems
  * Fix api break
  * Don't remove empty cells by default
  * Handle attached images in html converter
  * No need to check for the channels already running
  * Update ``font-awesome`` version for slides
  * Properly treat JSON data
  * Skip executing empty code cells
  * Ppdate log.warn (deprecated) to log.warning
  * Cleanup notebook.tex during PDF generation
  * Windows unicode error fixed, nosetest added to setup.py
  * Better content hiding; template & testing improvements
  * Fix Jinja syntax in custom template example.
  * Fix for an issue with empty math block
  * Add parser for Multiline math for LaTeX blocks
  * Use defusedxml to parse potentially untrusted XML
  * Fixes for traitlets 4.1 deprecation warnings
  + Testing, Docs, and Builds
  * A couple of typos
  * Add python_requires metadata.
  * Document ``--inplace`` command line flag.
  * Fix minor typo in ``usage.rst``
  * Add note about local ``reveal_url_prefix``
  * Move ``onlyif_cmds_exist`` decorator to test-specific utils
  * Include LICENSE file in wheels
  * Added Ubuntu Linux Instructions
  * Check for too recent of pandoc version
  * Removing more nose remnants via dependencies.
  * Remove offline statement and add some clarifications in slides docs
  * Linkify PR number
  * Added shebang for python
  * Upgrade mistune dependency
  * add feature to improve docs by having links to prs
  * Update notebook CSS from version 4.3.0 to 5.1.0
  * Explicitly exclude or include all files in Manifest.
- Use documentation provided by upstream.
* Thu Jul 26 2018 mcepl@suse.com
- Clean up SPEC file.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 5.3.1
  * MANIFEST.in updated to include ``LICENSE`` and ``scripts/`` when creating sdist. #666
- Update to 5.3
  + Major features
  * Tag Based Element Filtering
  + new features
  * configurable ``browser`` in ServePostProcessor #618
  * ``--clear-output`` command line flag to clear output in-place #619
  * remove elements based on tags with ``TagRemovePreprocessor``. #640, #643
  * CellExecutionError can now be imported from ``nbconvert.preprocessors`` #656
  * slides now can enable scrolling and custom transitions #600
  + Documentation
  * Release instructions for nbviewer-deploy
  * improved instructions for handling errors using the ``ExecutePreprocessor`` #656
  + Testing
  * better height/width metadata testing for images in rst & html #601 #602
  * normalise base64 output data to avoid false positives #650
  * normalise ipython traceback messages to handle old and new style #631
  + Bugfixes
  * mathjax obeys ``\\(\\)`` & ``\\[\\]`` (both nbconvert & pandoc) #609 #617
  * specify default templates using extensions #639
  * fix pandoc version number #638
  * require recent mistune version #630
  * catch errors from IPython ``execute_reply`` and ``error`` messages #642
  + Other
  * nose completely removed & dependency dropped #595 #660
  * mathjax processing in mistune now only uses inline grammar #611
  * removeRegex now enabled by default on all TemplateExporters, does not remove cells with outputs #616
  * validate notebook after applying each preprocessor (allowing additional attributes) #645
  * changed COPYING.md to LICENSE for more standard licensing that GitHub knows how to read #654
- Update to 5.2
  + Major features
  * Global Content Filtering
  * Execute notebooks from a function
  * Remove cells based on regex pattern
  * Script exporter entrypoints for nonpython scripts
  + New features
  * configurable ExecutePreprocessor.startup_timeout configurable #583
  * RemoveCell preprocessor based on cell content (defaults to empty cell) #575
  * function for executing notebooks: `executenb` #573
  * global filtering to remove inputs, outputs, markdown cells (&c.), this works on all templates #554
  * script exporter entrypoint #531
  * configurable anchor link text (previously ¶) `HTMLExporter.anchor_link_text` #522
  * configurable values for slides exporter #542 #558
  + Bugfixes
  * we now respect width and height metadata on jpeg and png mimetype outputs #588
  * now we respect the `resolve_references` filter in `report.tplx` #577
  * output metadata now is removed by ClearOutputPreprocessor #569
  * display id respected in execute preproessor #563
  * dynamic defaults for optional jupyter_client import #559
  * don't self-close non-void HTML tags #548
  * upgrade jupyter_client dependency to 4.2 #539
  * LaTeX output through md→LaTeX conversion shouldn't be touched #535
  * now we escape `<` inside math formulas when converting to html #514
  + Other
  * improved releases (how-to documentation, version-number generation and checking) #593
  * doc improvements  #593 #580 #565 #554
  * language information from cell magics (for highlighting) is now included in more formats #586
  * mathjax upgrades and cdn fixes #584 #567
  * better CI #571 #540
  * better traceback behaviour when execution errs #521
  * deprecated nose test features removed #519
* Wed Sep 13 2017 jmatejek@suse.com
- switch texlive Recommends to Suggests - let's not pull the whole
  texlive for this particular package
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 5.1.1
  * fix version numbering because of incomplete previous version number
- Update to 5.1
  * improved CSS (specifically tables, in line with notebook) #498
  * improve in-memory templates handling #491
  * test improvements #516 #509 #505
  * new configuration option: IOPub timeout #513
  * doc improvements #489 #500 #493 #506
  * newly customizable: output prompt #500
  * more python2/3 compatibile unicode handling #502
- Update to 5.0
  * Use :command:`xelatex` by default for latex export, improving unicode and font support.
  * Use entrypoints internally to access Exporters, allowing for packages to declare custom exporters more easily.
  * New ASCIIDoc Exporter.
  * New preprocessor for sanitised html output.
  * New general ``convert_pandoc`` filter to reduce the need to hard-code lists of filters in templates.
  * Use pytest, nose dependency to be removed.
  * Refactored Exporter code to avoid ambiguity and cyclic dependencies.
  * Update to traitlets 4.2 API.
  * Fixes for Unicode errors when showing execution errors on Python 2.
  * Default math font matches default Palatino body text font.
  * General documentation improvements. For example, testing, installation, custom exporters.
  * Improved link handling for LaTeX output
  * Refactored the automatic id generation.
  * New kernel_manager_class configuration option for allowing systems to be set up to resolve kernels in different ways.
  * Kernel errors now will be logged for debugging purposes when executing notebooks.
- Update to 4.3
  * added live widget rendering for html output, nbviewer by extension
- Update to 4.2
  * :ref:`Custom Exporters <external_exporters>` can be provided by external packages,
  and registered with nbconvert via setuptools entrypoints.
  * allow nbconvert reading from stdin with ``--stdin`` option (write into
  ``notebook`` basename)
  * Various ANSI-escape fixes and improvements
  * Various LaTeX/PDF export fixes
  * Various fixes and improvements for executing notebooks with ``--execute``.
- Create doc subpackage
* Mon Mar  7 2016 toddrme2178@gmail.com
- Update to 4.1.0
  * setuptools fixes for entrypoints on Windows
  * various fixes for exporters, including slides, latex, and PDF
  * fixes for exceptions met during execution
  * include markdown outputs in markdown/html exports
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Thu Aug 13 2015 toddrme2178@gmail.com
- Initial version
